# This file is an example script for using the qosr generator,
# and the policy generator together as part
# of the scenario generator
# Created by Mohammad Hassan, June 2002.

# source the generators code (this is not part of the release yet)
source topo-gen.tcl
source agent-gen.tcl
source qosr-gen.tcl
source policy-gen.tcl


# setup the files that will contain the scripts generated
set topofile topo1.tcl
set agentfile agent1.tcl
set qosrfile1 qosr1.tcl
set qosrfile2 qosr2.tcl
set policyfile policy1.tcl

# if we want to generate a hierarchical topology, inorder
# to be able to define end point distribution. valid only for 
# transit-stub topologies .
set hier_flag 1 

# we remove the agentfile, to start afresh... the agentfile is
# opened in append mode and previous runs may cause problems
if { [file exists $agentfile] } {
	catch { [exec rm $agentfile] }
}

# generate the topology creation script
#puts {topology -outfile $topofile -num 50 -connection_prob 0.1}
#topology -outfile $topofile -nodes 15 -connection_prob 0.1

#puts {topology -outfile $topofile -type transit_stub -nodes 50 -connection_prob 0.1}
#topology -outfile $topofile -type transit_stub -nodes 50 -connection_prob 0.1

puts {topology -outfile $topofile -type transit_stub -transit_nodes 1 -connection_prob 0.1}
topology -outfile $topofile -type mtransit_stub 


# generate the agent creation script
# note that src and dest stub location info (for distribution of src and dest nodes)
# should be given only when topology generated is of type transit-stub


#puts {agents -outfile $agentfile -transport TCP/Reno -src FTP -sink TCPSink/DelAck -num 60% -srcstub 1-4,8,10 -deststub 5-7,9,11,12 -start 1-3 -stop 9-11}

# agents -outfile $agentfile -transport TCP/Reno -src FTP -sink TCPSink/DelAck -num 60% -srcstub 1-4 -deststub 5-8 start 1-3 -stop 9-11

agents -outfile $agentfile -transport TCP/Reno -src FTP -sink TCPSink/DelAck -num 3 -srcstub 8 -deststub 3 -start 1-3 -stop 9-11

agents -outfile $agentfile -transport TCP/Reno -src FTP -sink TCPSink/DelAck -num 4 -srcstub 1 -deststub 4 -start 1-3 -stop 9-11

puts {agents -outfile $agentfile -transport TCP/Reno -src FTP -sink TCPSink/DelAck -num 60% -srcstub 1,3 -deststub 2,4 -start 1-3 -stop 9-11}

# agents -outfile $agentfile -transport TCP/Reno -src FTP -sink TCPSink/DelAck -start 1-3 -stop 9-11


#puts {agents -outfile $agentfile -transport TCP -sink TCPSink -num 8}
#agents -outfile $agentfile -transport TCP -sink TCPSink -num 8

#puts {agents -outfile $agentfile -transport SRM/Deterministic -num 75% \
	-join 0-2 -src CBR/UDP -traffic Pareto -srcnum 20% \
	-start 3-10}
#agents -outfile $agentfile -transport SRM/Deterministic -num 75% \
	-join 0-2 -src CBR/UDP -traffic Pareto -srcnum 20% \
	-start 3-10 

#puts {agents -outfile $agentfile -transport SRM -src CBR/UDP \
	-traffic Expoo }
#agents -outfile $agentfile -transport SRM -src CBR/UDP \
	-traffic Expoo

mark-end $agentfile
# the marker merely serves as debugging aid to make sure that
# all the code was written to file, and was not disrupted due
# to failure or disk full... etc, it also contains all the 
# the command lines used to generate the code.

policy -outfile $policyfile -q1min 10 -q1max 20 -q1prob 0.5 -qosr 1

qosr -outfile1 $qosrfile1 -outfile2 $qosrfile2

